<?php
/**
 * Copyright 2013 Drexel University
 */

// SPECIAL PAGE: This page is an upload form that saves a file directly on the IRODS server (no storage on the local server)


class SpecialIrodsUploadPage extends SpecialPage {

    function __construct() {
        require_once (dirname(__FILE__) . "/RodsWiki.functions.php");
        require_once (dirname(__FILE__) . "/RodsWiki.install.php");

        parent::__construct('SpecialIrodsUploadPage');
    }

    function execute($par) {
        global $wgOut, $wgScriptPath, $configIrodsRootPath, $wgUser;
        $this->setHeaders();

        //OpenRodsWiki($IrodsAccount);

        if ($wgUser->mId == 0) { // checks if there is an user logged in
            $wgOut->setPagetitle("Restricted access");
            $wgOut->addHTML("You should be logged in to have access to this page.");
            return;
        }

        // get the maximum file size
        $max_upload = (ini_get('upload_max_filesize'));
        $max_post = (ini_get('post_max_size'));
        $memory_limit = (ini_get('memory_limit'));
        $max_file_upload = min($max_upload, $max_post, $memory_limit);

        // this block uploads the file to irods
        $success = 0;
        if (isset($_FILES['uploadedfile'])) { // it is executed only if the form was submitted already
            $filename = basename($_FILES['uploadedfile']['name']);
            if (!existFile($configIrodsRootPath . get_wiki_file_path($filename)))
                if ($_POST['filename'] != "")
                    $filename = basename(get_wiki_file_path($_POST['filename']));

            if (preg_match('/\.[0-9]*$/i', $filename)) {
                $pathinfo = pathinfo($filename);
                $filename = $pathinfo['filename'];
            }

            $ok_to_upload = false;

            if ($_POST['options'] == 'advanced') {
                if (substr($_POST['irodspath'], strlen($_POST['irodspath']) - 1, 1) == '/')
                    $dest_file = $_POST['irodspath'] . $_POST['filename'];
                else
                    $dest_file = $_POST['irodspath'] . '/' . $_POST['filename'];

                $ok_to_upload = true;
                make_directory(dirname($_POST['irodspath']) . '/', basename($_POST['irodspath']));
            } else {
                $dest_file = $configIrodsRootPath . get_wiki_file_path($filename);


                make_directory($configIrodsRootPath, substr(md5($filename), 0, 1));
                make_directory($configIrodsRootPath . substr(md5($filename), 0, 1) . '/', substr(md5($filename), 0, 2));

                $ok_to_upload = true;
            }

            if ($ok_to_upload)
                if (uploadFileOnIrods($_FILES['uploadedfile']['tmp_name'], $dest_file)) {
                    if (isset($_POST['add_mediawiki_alias']))
                        addAVU($dest_file, 'wiki_alias', basename($dest_file), '');
                    $success = 1;
                }
        }

        if ($success) {
            if (isset($_GET['redir']))
                $redir = $_GET['redir'];
            elseif ($_POST['options'] == 'advanced')
                $redir = "http://" . $_SERVER['SERVER_NAME'] . $wgScriptPath . "/index.php/Special:IrodsMetadataPage?filename=" . $dest_file;
            else
                $redir = "http://" . $_SERVER['SERVER_NAME'] . $wgScriptPath . "/index.php/Special:IrodsMetadataPage?filename=" . $filename;

            die('<script>alert("File successfully uploaded!"); window.location = "' . $redir . '";</script><META HTTP-EQUIV="refresh" CONTENT="0;URL=' . $_GET['redir'] . '">');
        }


        if (!$success)
            $wgOut->addHTML("To include a file in a page, use a link in one of the following form: <br />
					<pre>{{#irods:" . ((isset($_GET['filename'])) ? ($_GET['filename']) : 'File.jpg') . "}}</pre>
					");

        // shows the upload form, no matter if the file was uploaded or not

        $wgOut->addWikiText("== Source file ==");


        $output = '<form enctype="multipart/form-data" action="http://' . $_SERVER[HTTP_HOST] . $_SERVER[REQUEST_URI] . '" method="POST" name="uploadform">';
        $output .= 'Choose a file to upload: <input name="uploadedfile" type="file" size = "50" onchange="change_filename(this.value); update_mediawiki_url(this.value);">';
        $output .= '<br /><br />';

        $output .= 'File name: <input type="text" name="filename" id="filename" onkeyup="onNameChange(this.value);update_mediawiki_url(this.value)" size="50"' . (isset($_GET['filename']) ? ' value="' . $_GET['filename'] . '"' : '') . '> (change this if you want to upload this file with another name on Irods)<br><br>';
        $output .= 'Maximum file size: ' . $max_file_upload . '<br>';
        $output .= '<div id="file_exists" style="display: none"><font color="red">&#9888; Warning: This file already exists!</font></div>';
        $output .= '<div id="file_safe" style="display: none"><font color="green">&#10003; This file could be uploaded safely!</font></div><br>';

        
        $output .= '<script> configIrodsRootPath = "' . $configIrodsRootPath . '"; wikiBaseUrl = "http://' . $_SERVER[HTTP_HOST] . $wgScriptPath . '"; filenameLocked = ' . ((int) isset($_GET['filename'])) . ';</script>';
        $output .= '<script src="' . $wgScriptPath . '/extensions/RodsWiki/md5.js"></script>';
        $output .= '<script src="' . $wgScriptPath . '/extensions/RodsWiki/SpecialUpload.js"></script>';
        $output .= '<input type="radio" value="default" name="options" onclick="$(\'#advanced\').hide(\'slow\'); update_mediawiki_url(this.value);" id="radio_options" checked="checked"> <b>Default options</b><br>';
        $output .= '<input type="radio" value="advanced" name="options" onclick="$(\'#advanced\').show(\'slow\');" id="radio_options"> <b>Advanced options</b>';
        $output .= '<div id="advanced" style="display:none">';
        $output .= 'Add MediaWiki Alias <input type="checkbox" name="add_mediawiki_alias" id="add_mediawiki_alias" checked="checked"> <br /><i>(this allows you to refer to this file using the filename only, instead of the whole path)</i><br><br>';
        $output .= 'iRODS upload path: <input type="text" size="50" name="irodspath" id="irodspath" onkeyup="onPathEdited();"> <input type="hidden" value="0" id="irods_path_edited" name="irods_path_edited">';
        $output .= '</div><br><br>';
        $output .= '<div id="results"></div>';
        $output .= '<input type="submit" value="Upload File" name="upload_button" id="upload_button" /></form>';

        $wgOut->addHTML($output);

        $wgOut->setPagetitle("Upload mediafile");
    }

}

?>
